==> lusid_sdk-0.9.93-py2.py3-none-any.whl: lusid/models/upsert_instrument_properties_response.py <==
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright © 2018 FINBOURNE TECHNOLOGY LTD
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UpsertInstrumentPropertiesResponse(Model):
    """UpsertInstrumentPropertiesResponse.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param href:
    :type href: str
    :ivar failed: A list of any values that failed to be upserted.
    :vartype failed: list[~lusid.models.ErrorDetail]
    :param links:
    :type links: list[~lusid.models.Link]
    """

    _validation = {
        'failed': {'readonly': True},
    }

    _attribute_map = {
        'href': {'key': 'href', 'type': 'str'},
        'failed': {'key': 'failed', 'type': '[ErrorDetail]'},
        'links': {'key': 'links', 'type': '[Link]'},
    }

    def __init__(self, href=None, links=None):
        super(UpsertInstrumentPropertiesResponse, self).__init__()
        self.href = href
        self.failed = None
        self.links = links

==> lusid_sdk-0.9.162-py2.py3-none-any.whl: lusid/models/upsert_instrument_properties_response.py <==
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright © 2018 FINBOURNE TECHNOLOGY LTD
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UpsertInstrumentPropertiesResponse(Model):
    """UpsertInstrumentPropertiesResponse.

    :param as_at_date:
    :type as_at_date: datetime
    :param links:
    :type links: list[~lusid.models.Link]
    """

    _validation = {
        'as_at_date': {'required': True},
    }

    _attribute_map = {
        'as_at_date': {'key': 'asAtDate', 'type': 'iso-8601'},
        'links': {'key': 'links', 'type': '[Link]'},
    }

    def __init__(self, as_at_date, links=None):
        super(UpsertInstrumentPropertiesResponse, self).__init__()
        self.as_at_date = as_at_date
        self.links = links
